@@ -3,12 +3,10 @@
 
 import time
 import board
-import busio
-import adafruit_dps310
+from adafruit_dps310.basic import DPS310
 
-i2c = busio.I2C(board.SCL, board.SDA)
-
-dps310 = adafruit_dps310.DPS310(i2c)
+i2c = board.I2C()  # uses board.SCL and board.SDA
+dps310 = DPS310(i2c)
 
 while True:
     print("Temperature = %.2f *C" % dps310.temperature)
